@@ -9,7 +9,7 @@ In this context, a "plugin" is simply a Python module with a defined
 interface.
 '''
 
-# Copyright (C) 2016 Antoine Beaupré <anarcat@debian.org>
+# Copyright (C) 2016-2019 Antoine Beaupré <anarcat@debian.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -33,7 +33,7 @@ import logging
 import shlex
 
 
-def output(feed, item, lock=None):
+def output(feed, item, lock=None, session=None):
     """load and run the given plugin with the given arguments
 
     an "output plugin" is a simple Python module with an ``output``
@@ -52,6 +52,10 @@ def output(feed, item, lock=None):
     the provided ``lock`` (a multiprocessor.Lock object) to acquire
     and release locks around contentious resources.
 
+    Finally, the FeedManager will pass along his own ``session`` that
+    should be reused by plugins to do requests. This allows plugins to
+    be unit-tested and leverages the built-in cache as well.
+
     The following keywords are usually replaced in the arguments:
 
     * {item.link}
@@ -102,7 +106,7 @@ def output(feed, item, lock=None):
                       plugin, args)
         plugin = importlib.import_module(plugin)
         try:
-            return plugin.output(*args, feed=feed, item=item, lock=lock)
+            return plugin.output(*args, feed=feed, item=item, lock=lock, session=session)
         except (BrokenPipeError):
             # handle pipe errors gracefully, e.g. | head
             raise
@@ -113,7 +117,7 @@ def output(feed, item, lock=None):
         return False
 
 
-def filter(feed, item, lock=None):
+def filter(feed, item, lock=None, session=None):
     """call filter plugins.
 
     very similar to the output plugin, but just calls the ``filter``
@@ -133,7 +137,7 @@ def filter(feed, item, lock=None):
                       plugin, args)
         plugin = importlib.import_module(plugin)
         try:
-            return plugin.filter(*args, feed=feed, item=item, lock=lock)
+            return plugin.filter(*args, feed=feed, item=item, lock=lock, session=session)
         except Exception as e:
             logging.exception("plugin generated exception: %s, ignoring", e)
             return None
